/***********************************
 * Author: Matt Christian
 * 
 * Description: Implements a Game State
 * 
 * Notes: For use with XNA Development Tutorials
 * 
 * If you use this for a project, please give credit!
 * http://matt.insidegamer.org/xnatutorials.aspx
 * 
 * ***********************************/
#region Using Statements
using System;
using System.Collections.Generic;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Net;
using Microsoft.Xna.Framework.Storage;
#endregion

namespace WindowsGame1
{
    public class GameState
    {
        //Bools defining state
        private bool _InGame;
        private bool _Paused;
        private bool _Loading;

        //Temp string to store state
        private String _stateStore;

        /// <summary>
        /// GameState Constructor (Resets States)
        /// </summary>
        public GameState()
        {
            ResetStates();
        }

        /// <summary>
        /// GameState Destructor
        /// </summary>
        ~GameState()
        {

        }

        /// <summary>
        /// Resets all states
        /// </summary>
        public void ResetStates()
        {
            InGame = false;
            Paused = false;
            Loading = false;
        }

        /// <summary>
        /// Stores currently set state
        /// </summary>
        public void StoreState()
        {
            if (InGame)
                _stateStore = "InGame";

            if (Paused)
                _stateStore = "Paused";

            if (Loading)
                _stateStore = "Loading";
        }

        /// <summary>
        /// Restores currently saved state
        /// </summary>
        public void RestoreState()
        {
            ResetStates();

            if (_stateStore == "InGame")
                _InGame = true;

            if (_stateStore == "Paused")
                _Paused = true;

            if (_stateStore == "Loading")
                _Loading = true;
        }

        /// <summary>
        /// Get or set to true creates In-Game state
        /// </summary>
        public bool InGame
        {
            get { return _InGame; }
            set { _InGame = value; }
        }

        /// <summary>
        /// Get or set to true creates Loading state
        /// </summary>
        public bool Loading
        {
            get { return _Loading; }
            set { _Loading = value; }
        }

        /// <summary>
        /// Get or set to true creates Paused state
        /// </summary>
        public bool Paused
        {
            get { return _Paused; }
            set { _Paused = value; }
        }

    }
}